@@ -308,13 +308,24 @@ impl TryFrom<&mut ModelAssembler> for Model {
                 .iter()
                 .map(|file_name| value.read_model(&file_name))
                 .collect();
+            debug!(
+                "Model::try_from::<ModelAssembler>(...): found models => {:#?}",
+                &models
+            );
             match models {
                 Ok(mut models) => {
-                    let mut merged = models.remove(0);
-                    for other in models {
-                        merged.merge(other)?;
+                    if models.len() == 0 {
+                        warn!(
+                            "Model::try_from::<ModelAssembler>(...): No models found to assemble!"
+                        );
+                        Ok(Model::default())
+                    } else {
+                        let mut merged = models.remove(0);
+                        for other in models {
+                            merged.merge(other)?;
+                        }
+                        Ok(merged)
                     }
-                    Ok(merged)
                 }
                 Err(err) => Err(err),
             }
@@ -331,10 +342,13 @@ impl ModelAssembler {
             "ModelAssembler::with_registry({:?})",
             file_types.extensions().collect::<Vec<&String>>()
         );
-        Self::init(Self {
-            file_types,
-            paths: Default::default(),
-        })
+        Self::init(
+            Self {
+                file_types,
+                paths: Default::default(),
+            },
+            ENV_PATH_NAME,
+        )
     }
 
     ///
@@ -372,7 +386,7 @@ impl ModelAssembler {
     /// supported file extensions as well as finding files recursively in directory paths.
     ///
     pub fn expand_file_paths(&self) -> Vec<PathBuf> {
-        info!("ModelAssembler::into_file_paths()");
+        info!("ModelAssembler::expand_file_paths()");
         let mut results = Vec::default();
         for path in &self.paths {
             self.expand_path(path, &mut results);
@@ -382,9 +396,9 @@ impl ModelAssembler {
 
     // --------------------------------------------------------------------------------------------
 
-    fn init(self) -> Self {
+    fn init(self, search_path: &str) -> Self {
         let mut mut_self = self;
-        if let Ok(search_path) = env::var(ENV_PATH_NAME) {
+        if let Ok(search_path) = env::var(search_path) {
             info!("ModelAssembler::init() - {}", search_path);
             for path in search_path.split(':') {
                 let path = path.trim();
@@ -422,7 +436,6 @@ impl ModelAssembler {
 
     fn read_model(&self, path: &Path) -> Result<Model> {
         info!("ModelAssembler::read_model({:?})", path);
-        println!("{:?}", path);
         if let Some(extension) = path.extension() {
             let extension = extension.to_string_lossy().to_lowercase();
             if let Some(file_type) = self.file_types.get(extension.as_ref()) {
